# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-30 07:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_mission', '0013_auto_20181130_1346'),
    ]

    operations = [
        migrations.AlterField(
            model_name='missiontype',
            name='conditions',
            field=models.TextField(blank=True, help_text='\u683c\u5f0f\u4e3a\uff1a[\u6761\u4ef61\uff1a\u503c1;\u6761\u4ef62\uff1a\u503c2]\uff0c\u591a\u4e2a\u6761\u4ef6\u7528;\u5206\u5272', null=True, verbose_name='\u5176\u4ed6\u9644\u52a0\u6761\u4ef6'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-19 12:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_mission', '0014_auto_20181130_1533'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mission',
            options={'ordering': ['created_at'], 'permissions': (('view_mission_list', '\u67e5\u770b\u4efb\u52a1\u5217\u8868'),)},
        ),
        migrations.AlterModelOptions(
            name='stage',
            options={'ordering': ['level'], 'permissions': (('view_stage_list', '\u67e5\u770b\u9636\u6bb5\u5217\u8868'),)},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-30 05:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_mission', '0012_auto_20181129_1444'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mission',
            options={'ordering': ['created_at']},
        ),
    ]
